@@ -1,8 +1,8 @@
-from typing import Self
+# from typing import Self
 
 
 class ContextLocal:
-    _backend_registry: dict[str, type[Self]] = {}
+    _backend_registry: dict[str, type["ContextLocal"]] = {}
 
     def __new__(cls, *args, backend=None, **kwargs):
         if backend is None:
